@@ -1,7 +1,7 @@
 package Minion::Backend::Mango;
 use Mojo::Base 'Minion::Backend';
 
-our $VERSION = '0.94';
+our $VERSION = '0.95';
 
 use Mango;
 use Mango::BSON qw(bson_oid bson_time bson_doc);
@@ -219,11 +219,12 @@ sub _worker_info {
   return undef unless my $worker = shift;
   my $cursor = $self->jobs->find({state => 'active', worker => $worker->{_id}});
   return {
-    host    => $worker->{host},
-    id      => $worker->{_id},
-    jobs    => [map { $_->{_id} } @{$cursor->all}],
-    pid     => $worker->{pid},
-    started => $worker->{started}->to_epoch
+    host     => $worker->{host},
+    id       => $worker->{_id},
+    jobs     => [map { $_->{_id} } @{$cursor->all}],
+    pid      => $worker->{pid},
+    started  => $worker->{started}->to_epoch,
+    notified => $worker->{notified}->to_epoch
   };
 }
 
